# Security Policy

## Supported Versions

Only the most recent version of Zing is supported with security updates.

## Reporting a Vulnerability

To report a security vulnerability, please use GitHub's security advisory feature:

https://github.com/Farmer-Pete/Zing/security
